Identity Service (IAM)
======================

The Identity client is the command-line interface (CLI) for the Identity
Service (IAM) API, while IAM is for its extensions.

For help on a specific `identity` command, enter:

.. code-block:: console

   $ openstack identity help SUBCOMMAND

For help on a specific `iam` command, enter:

.. code-block:: console

   $ openstack iam help SUBCOMMAND
